Learn R Programming

metavcov (version 2.1.5)

metafixed: Fitting Fixed-Effect Meta-Analysis Models

Description

The function metafixed performs fixed-effects multivariate meta-analysis with the generalized least squares (GLS) method.

Usage

metafixed(y, Slist)

Value

The metafixed function typically returns a list object of class "metafixed" representing the meta-analytical model. Use the summary function to check the analysis results.

Author

Min Lu

Arguments

y

A \(N \times p\) matrix or data frame that stores effect sizes from \(N\) primary studies. Usually the output value ef produced by r.vcov for correlation coefficients or mix.vcov for other types of effect sizes.

Slist

A \(N\)-dimensional list of \(p(p+1)/2 \times p(p+1)/2\) matrices that stores within-study (co)variance matrices of the estimated effect sizes for each one of the \(N\) studies. Usually the output value list.vcov produced by r.vcov for correlation coefficients or mix.vcov for other types of effect sizes.

Details

Estimators were calculated from the generalized least squares approach.

References

Lu, M. (2023). Computing within-study covariances, data visualization, and missing data solutions for multivariate meta-analysis with metavcov. Frontiers in Psychology, 14:1185012.

Cooper, H., Hedges, L.V., & Valentine, J.C. (Eds.) (2009). The handbook of research synthesis and meta-analysis. New York: Russell Sage Foundation.

Examples

Run this code
######################################################
# Example: Craft2003 data
# Preparing covariances for multivariate meta-analysis
######################################################
data(Craft2003)
computvcov <- r.vcov(n = Craft2003$N,
                     corflat = subset(Craft2003, select = C1:C6),
                     method = "average")
y <- computvcov$ef
Slist <- computvcov$list.vcov
#####################################################
# Running fixed-effects model using "metafixed"
#####################################################
MMA_FE <- summary(metafixed(y = y, Slist = Slist))
MMA_FE$coefficients
##############################################################
# Plotting the result:
##############################################################
plotCI(y = computvcov$ef, v = computvcov$list.vcov,
        name.y = NULL, name.study = Craft2003$ID,
        y.all = MMA_FE$coefficients[,1],
        y.all.se = MMA_FE$coefficients[,2],
        up.bound = Inf, low.bound = -Inf)

Run the code above in your browser using DataLab